# Sys::Tlock::Config.pm
# Dummy module. Overwritten at install time.

package Sys::Tlock::Config;
use strict;

our $home;

1;

__END__
